Keyboard shortcuts

Press or to navigate between chapters

Press S or / to search in the book

Press ? to show this help

Press Esc to hide this help

BasketTradeOwnership

Git Source

Struct representing a baskets ownership of an external trade.

struct BasketTradeOwnership {
// Address of the basket.
address basket;
// Ownership of the trade with a base of 1e18. An ownershipe of 1e18 means the basket owns the entire trade.
uint96 tradeOwnership;
}