BasketTradeOwnership
Struct representing a baskets ownership of an external trade.
struct BasketTradeOwnership {
// Address of the basket.
address basket;
// Ownership of the trade with a base of 1e18. An ownershipe of 1e18 means the basket owns the entire trade.
uint96 tradeOwnership;
}